@@ -6,7 +6,7 @@ from sklearn.datasets import make_moons
 
 class HalfMoonIterator(DatasetIterator):
 
-    def __init__(self, seed: int, noise_std: float, num_samples: List[int]):
+    def __init__(self, seed: int, noise_std: float, num_samples: List[int], translation: List[int] = None):
         """
         Creates a dataset iterator over the function x -> x^3 + e, where e ~ N(0, noise_std^2).
 
@@ -17,7 +17,9 @@ class HalfMoonIterator(DatasetIterator):
         """
         self.X, self.y = make_moons(n_samples=num_samples, shuffle=True, noise=noise_std, random_state=seed)
         self.X = torch.Tensor(self.X)
-        self.y = torch.Tensor(self.y)
+        if translation is not None:
+            self.X = self.X + torch.Tensor(translation)
+        self.y = torch.IntTensor(self.y)
 
     def __len__(self):
         return len(self.y)
@@ -27,4 +29,4 @@ class HalfMoonIterator(DatasetIterator):
         :param index: index within dataset
         :return: sample, target, tag
         """
-        return self.X[index], self.y[index], self.y[index]
+        return self.X[index], int(self.y[index]), int(self.y[index])
